<template>
  <div class="edit-add-detail">
    <!-- <div class="crumbs">
      <Breadcrumb :breadcrumbOpt="breadcrumbOpt" svg-name="#icon-zuhuguanli" @breadcrumb-click="handleClose" />
    </div> -->
    <div class="form-content">
      <el-form ref="formInfo" :model="parameter" label-width="100px" :rules="rules" label-position="top">
        <div class="rows">
          <div class="rows-left">
            <div class="rows-hr"></div>
          </div>
          <div class="rows-title">
            <div class="text-overflow">基本信息</div>
          </div>
        </div>
        <el-row :gutter="24">
          <el-col :span="8">
            <el-form-item label="客户名称" prop="clientsName">
              <el-input clearable v-model="parameter.clientsName" placeholder="请输入客户名称"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="证件类型" prop="cardType">
              <el-select v-model="parameter.cardType" clearable placeholder="请选择证件类型" style="width: 100%;">
                <el-option v-for="item in zjlx" :key="item.value" :label="item.name" :value="item.value">
                </el-option>
              </el-select>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="证件号码" prop="cardNo">
              <el-input clearable v-model="parameter.cardNo" placeholder="请输入证件号码"></el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="8">
            <el-form-item label="所属公司" prop="belongsOrgId">
              <el-cascader ref="cascader" v-model="orgValue" style="width: 100%;" :options="orgTree"
                           :show-all-levels="false" @change="handelCascader"
                           :props="{ label: 'name', value: 'id', expandTrigger: 'hover', checkStrictly: true }"></el-cascader>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="开户银行" prop="bankName">
              <el-input clearable v-model="parameter.bankName" placeholder="请输入开户银行"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="银行账号" prop="bankNo">
              <el-input clearable type="number" v-model="parameter.bankNo" placeholder="请输入银行账号"></el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="8">
            <el-form-item label="联系电话" prop="contactTel">
              <el-input clearable v-model="parameter.contactTel" placeholder="请输入联系电话"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="通信地址">
              <el-input clearable v-model="parameter.address" placeholder="请输入通信地址"></el-input>
            </el-form-item>
          </el-col>
          <el-col :span="8">
            <el-form-item label="E-mail">
              <el-input clearable v-model="parameter.email" placeholder="请输入E-mail"></el-input>
            </el-form-item>
          </el-col>
        </el-row>
        <el-row :gutter="24">
          <el-col :span="24">
            <el-form-item label="备注">
              <el-input type="textarea" :rows="2" placeholder="请输入备注" v-model="parameter.remark">
              </el-input>
            </el-form-item>
          </el-col>
        </el-row>
      </el-form>
    </div>
    <div slot="footer" class="footer">
      <el-button type="primary" @click="handleSave">{{
          $t('domestic.save')
        }}
      </el-button>
      <el-button @click="handleClose">{{ $t('domestic.cancel') }}</el-button>
    </div>
  </div>
</template>

<script>
import Breadcrumb from '@/components/Breadcrumb/index.vue'
import utils from '@/utils.js'
import api from '@/api/assetsOperating/profilesCustomer/IndividualCustomers.js'
import pubSub from 'pubsub-js'

export default {
  name: 'domesticDialog',
  components: {Breadcrumb},
  data() {
    return {
      breadcrumbOpt: [{breadcrumbName: '个人客户'}, {breadcrumbName: '添加'}],
      cardTypeData: [],
      parameter: {
        clientsName: '',
        cardType: '',
        cardNo: '',
        belongsOrgId: '',
        bankName: '',
        bankNo: '',
        contactTel: '',
        address: '',
        email: '',
        clientsType: 1,
        clientsStatus: 0
      },
      rules: {
        clientsName: [
          {
            required: true,
            message: '请输入客户名称',
            trigger: 'blur'
          }
        ],
        cardNo: [
          {
            required: true,
            message: '请输入证件号码',
            trigger: 'blur'
          },
          {
            pattern: /^[a-zA-Z0-9]+$/,
            message: '证件号码格式不正确',
            trigger: 'blur'
          }
        ],
        contactTel: [
          {
            required: true,
            message: '请输入联系电话',
            trigger: 'blur'
          },
          {
            pattern: /^1[3456789]\d{9}$/,
            message: '手机号码格式不正确',
            trigger: 'blur'
          }
        ],
        bankName: [
          {
            required: true,
            message: '请输入开户银行',
            trigger: 'blur'
          }
        ],
        bankNo: [
          {
            required: true,
            message: '请输入银行账号',
            trigger: 'blur'
          }
        ],
        cardType: [
          {
            required: true,
            message: '请选择证件类型',
            trigger: 'blur'
          }
        ],
        belongsOrgId: [
          {
            required: true,
            message: '请选择所属公司',
            trigger: 'blur'
          }
        ]
      },
      orgValue: [],
      orgTree: [],//组织树

      orgId: ''//组织id

    }
  },
  created() {
    let curUserDetail = this.$store.state.user.currentUserDetail
    this.orgId = curUserDetail.org[0].orgId
    this.zjlx = utils.getDictItemsFromCache('zjlx')
    this.getUserOrgTree()
  },
  mounted() {
  },
  methods: {
    //编辑
    addModifyBtn(val) {
      this.parameter.cardType = this.zjlx[0].value
      this.$set(this.parameter)
      if (val) {
        this.breadcrumbOpt[1].breadcrumbName = '编辑'
        this.modifychoData(val)
      } else {
        this.breadcrumbOpt[1].breadcrumbName = '添加'
        this.orgValue = utils.getAllParentArr(this.orgTree, this.orgId, 'id', 'children')
        this.$set(this.orgValue)
        this.$nextTick(() => {
          this.handelCascader()
        })
      }
    },
    //获取组织树
    getUserOrgTree() {
      api.getUserOrgTree(this.orgId, res => {
        if (res) {
          this.orgTree = res
        }
      })
    },
    //获取修改回显数据
    modifychoData(val) {
      api.detailsData(val.id, res => {
        if (res) {
          this.parameter = res
          if (res.belongsOrgFullId) {
            let orgId = utils.trimSpace(res.belongsOrgFullId.split('.')).pop()
            this.orgValue = utils.getAllParentArr(this.orgTree, orgId, 'id', 'children')
          }
        }
      })
    },
    //绑定所属公司
    handelCascader() {
      let data = this.$refs['cascader'].getCheckedNodes()[0].data
      this.parameter.belongsOrgFullId = data.path
      this.parameter.belongsOrgId = data.id
      this.parameter.belongsOrgName = data.name
    },
    // 关闭//面包屑点击
    handleClose() {
      pubSub.publish('go-back')


      this.$emit('closeComponent')
      this.parameter = {
        clientsType: 1,
        clientsStatus: 0
      }
      this.$refs.formInfo.clearValidate()
    },
    // 保存
    handleSave() {
      this.$refs.formInfo.validate(valid => {
        if (valid) {
          if (this.breadcrumbOpt[1].breadcrumbName === '添加') {
            api.addData(this.parameter, res => {
              if (res.state) {
                this.$message.success('保存成功')
                this.handleClose()
              }
            })
          } else if (this.breadcrumbOpt[1].breadcrumbName === '编辑') {
            api.editData(this.parameter, res => {
              if (res.state) {
                this.$message.success('编辑成功')
                this.handleClose()
              }
            })
          }
        }
      })
    }
  }
}
</script>

<style lang="scss" scoped>
.edit-add-detail {
  display: flex;
  flex-direction: column;

  // .crumbs {
  // }
  .form-content {
    flex: 1;
    // height: 80%;
    background-color: white;
    padding: 10px 20px;
    // margin-top: 20px;
    border-radius: 10px;
    overflow-y: scroll;
  }

  .form-content::-webkit-scrollbar {
    display: none;
    /* Chrome Safari */
  }

  .footer {
    height: 100px;
    background-color: white;
    margin-top: 20px;
    display: flex;
    justify-content: center;
    align-items: center;
  }
}

.rows {
  display: flex;
  align-items: center;
  border-bottom: 1px solid #ebebeb;
  margin-bottom: 16px;
  padding: 10px 0;

  .rows-left {
    margin-right: 10px;

    .rows-hr {
      width: 3px;
      height: 18px;
      background-color: #0e6eff;
      border-radius: 2px;
    }
  }

  .rows-title {
    .text-overflow {
      width: 100%;
      font-size: 16px;
    }
  }
}
</style>
